@@ -92,7 +92,7 @@ func jsInit() {
 
 	JSR, JSW, err = os.Pipe()
 	if err != nil {
-		panic(err)
+		log.Fatalln(err)
 	}
 	for i := uint64(0); i < jobs; i++ {
 		jsRelease("initial fill")
@@ -101,7 +101,7 @@ func jsInit() {
 
 func jsReleaseNoLock() {
 	if n, err := JSW.Write([]byte{0}); err != nil || n != 1 {
-		panic("can not write JSW")
+		log.Fatalln("can not write JSW:", err)
 	}
 }
 
@@ -124,7 +124,7 @@ func jsAcquire(ctx string) {
 	}
 	trace(CJS, "acquire for %s", ctx)
 	if n, err := JSR.Read([]byte{0}); err != nil || n != 1 {
-		panic("can not read JSR")
+		log.Fatalln("can not read JSR:", err)
 	}
 	jsTokensM.Lock()
 	jsTokens++
