@@ -160,10 +160,11 @@ func main() {
 	if *flagTraceAll {
 		mustSetenv(EnvTrace, "1")
 	}
-	if *flagTrace {
+	if os.Getenv(EnvTrace) == "1" {
+		TracedAll = true
 		traced = true
 	} else {
-		traced = os.Getenv(EnvTrace) == "1"
+		traced = *flagTrace
 	}
 
 	// Those are internal envs
@@ -188,7 +189,7 @@ func main() {
 		if err = unix.Flock(int(fdLock.Fd()), unix.LOCK_EX); err != nil {
 			panic(err)
 		}
-		if _, err = fd.Seek(0, os.SEEK_SET); err != nil {
+		if _, err = fd.Seek(0, io.SeekStart); err != nil {
 			panic(err)
 		}
 		tgtsRaw, err := ioutil.ReadAll(bufio.NewReader(fd))
@@ -327,7 +328,7 @@ CmdSwitch:
 		if err != nil {
 			break
 		}
-		_, err = fdTmp.Seek(0, os.SEEK_SET)
+		_, err = fdTmp.Seek(0, io.SeekStart)
 		if err != nil {
 			break
 		}
