@@ -35,7 +35,7 @@ import (
 	"time"
 
 	"go.cypherpunks.ru/recfile"
-	"go.cypherpunks.ru/tai64n"
+	"go.cypherpunks.ru/tai64n/v2"
 	"golang.org/x/sys/unix"
 )
 
@@ -67,6 +67,8 @@ var (
 	flagTraceAll     = flag.Bool("xx", false, fmt.Sprintf("trace (sh -x) all targets (%s=1)", EnvTrace))
 	flagStderrKeep   = flag.Bool("logs", false, fmt.Sprintf("keep job's stderr (%s=1)", EnvStderrKeep))
 	flagStderrSilent = flag.Bool("silent", false, fmt.Sprintf("do not print job's stderr (%s=1)", EnvStderrSilent))
+
+	TracedAll bool
 )
 
 type RunErr struct {
@@ -304,7 +306,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		args = make([]string, 0, 3)
 	} else {
 		cmdName = "/bin/sh"
-		if traced {
+		if traced || TracedAll {
 			args = append(args, "-ex")
 		} else {
 			args = append(args, "-e")
@@ -464,9 +466,9 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 					continue
 				}
 				if fdStderr != nil {
-					tai64n.FromTime(time.Now(), ts)
+					ts.FromTime(time.Now())
 					LogMutex.Lock()
-					fmt.Fprintf(fdStderr, "%s %s\n", ts.Encode(), line)
+					fmt.Fprintln(fdStderr, tai64n.Encode(ts[:]), line)
 					LogMutex.Unlock()
 				}
 				if StderrSilent {
