@@ -96,9 +96,9 @@ func statusInit() {
 					CJS, done, CReset,
 				)
 			}
+			out = erasedStatus(out, "\r")
 			LogMutex.Lock()
-			os.Stderr.WriteString(erasedStatus(out, "\r"))
-			LogWasStatus = true
+			os.Stderr.WriteString(out)
 			LogMutex.Unlock()
 		}
 	}()
